==> openjfx_11.0.2+1.orig.tar.xz: openjdk-jfx-11.0.2-1/modules/javafx.web/src/main/native/Source/JavaScriptCore/API/JSCTestRunnerUtils.cpp <==
/*
 * Copyright (C) 2013 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "JSCTestRunnerUtils.h"

#include "APICast.h"
#include "JSCInlines.h"
#include "TestRunnerUtils.h"

namespace JSC {


JSValueRef failNextNewCodeBlock(JSContextRef context)
{
    ExecState* exec= toJS(context);
    JSLockHolder holder(exec);
    return toRef(exec, failNextNewCodeBlock(exec));
}

JSValueRef numberOfDFGCompiles(JSContextRef context, JSValueRef theFunctionValueRef)
{
    ExecState* exec= toJS(context);
    JSLockHolder holder(exec);
    return toRef(exec, numberOfDFGCompiles(toJS(exec, theFunctionValueRef)));
}

JSValueRef setNeverInline(JSContextRef context, JSValueRef theFunctionValueRef)
{
    ExecState* exec= toJS(context);
    JSLockHolder holder(exec);
    return toRef(exec, setNeverInline(toJS(exec, theFunctionValueRef)));
}

JSValueRef setNeverOptimize(JSContextRef context, JSValueRef theFunctionValueRef)
{
    ExecState* exec= toJS(context);
    JSLockHolder holder(exec);
    return toRef(exec, setNeverOptimize(toJS(exec, theFunctionValueRef)));
}

} // namespace JSC

==> openjfx_11.0.11+0.orig.tar.xz: openjdk-jfx-11.0.11-0/modules/javafx.web/src/main/native/Source/JavaScriptCore/API/JSCTestRunnerUtils.cpp <==
/*
 * Copyright (C) 2013 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "JSCTestRunnerUtils.h"

#include "APICast.h"
#include "JSCInlines.h"
#include "TestRunnerUtils.h"

namespace JSC {


JSValueRef failNextNewCodeBlock(JSContextRef context)
{
    JSGlobalObject* globalObject= toJS(context);
    JSLockHolder holder(globalObject);
    return toRef(globalObject, failNextNewCodeBlock(globalObject));
}

JSValueRef numberOfDFGCompiles(JSContextRef context, JSValueRef theFunctionValueRef)
{
    JSGlobalObject* globalObject= toJS(context);
    JSLockHolder holder(globalObject);
    return toRef(globalObject, numberOfDFGCompiles(toJS(globalObject, theFunctionValueRef)));
}

JSValueRef setNeverInline(JSContextRef context, JSValueRef theFunctionValueRef)
{
    JSGlobalObject* globalObject= toJS(context);
    JSLockHolder holder(globalObject);
    return toRef(globalObject, setNeverInline(toJS(globalObject, theFunctionValueRef)));
}

JSValueRef setNeverOptimize(JSContextRef context, JSValueRef theFunctionValueRef)
{
    JSGlobalObject* globalObject= toJS(context);
    JSLockHolder holder(globalObject);
    return toRef(globalObject, setNeverOptimize(toJS(globalObject, theFunctionValueRef)));
}

} // namespace JSC
